#
# spec file for package perl-HTML-Strip
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name HTML-Strip
Name:           perl-HTML-Strip
Version:        2.120.0
Release:        1699.1.pm.3
# 2.12 -> normalize -> 2.120.0
%define cpan_version 2.12
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perl extension for stripping HTML markup from text
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/K/KI/KILINRAX/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::Exception)
Requires:       perl(Test::Exception)
Provides:       perl(HTML::Strip) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
This module simply strips HTML-like markup from text rapidly and brutally.
It could easily be used to strip XML or SGML markup instead - but as
removing HTML is a much more common problem, this module lives in the
HTML:: namespace.

It is written in XS, and thus about five times quicker than using regular
expressions for the same task.

It does _not_ do any syntax checking. If you want that, use HTML::Parser.
Instead it merely applies the following rules:

* 1

Anything that looks like a tag, or group of tags will be replaced with a
single space character. Tags are considered to be anything that starts with
a '<' and ends with a '>'; with the caveat that a '>' character may appear
in either of the following without ending the tag:

  * Quote

Quotes are considered to start with either a ''' or a '"' character, and
end with a matching character _not_ preceded by an even number or escaping
slashes (i.e. '\"' does not end the quote but '\\\\"' does).

  * Comment

If the tag starts with an exclamation mark, it is assumed to be a
declaration or a comment. Within such tags, '>' characters do not end the
tag if they appear within pairs of double dashes (e.g. '<!-- <a
href="old.htm">old page</a> -->' would be stripped completely). No parsing
for quotes is performed within comments, so for instance '<!-- comment with
both ' quote types " -->' would be entirely stripped.

* 2

Anything that appears between tags which we term _strip tags_ is removed.
By default, these tags are 'title', 'script', 'style' and 'applet'.

HTML::Strip maintains state between calls, so you can parse a document in
chunks should you wish. If a call to 'parse()' ends half-way through a tag,
quote or comment; the next call to 'parse()' expects its input to carry on
from that point.

If this is not the behaviour you want, you can either call 'eof()' between
calls to 'parse()', or set 'auto_reset' to true (either on the constructor
or with 'set_auto_reset') so that the parser will reset after each call.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README

%changelog
* Tue Mar 21 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.12
  see /usr/share/doc/packages/perl-HTML-Strip/Changes
  2.12  Mon 20 Mar 2023 19:17:06 EET
  - update META.yml to version 2 spec
    (patch contributed by Boyd Duffee)
  - fixes test failure in t/420_pod_coverage.t with Test::Pod::Coverage installed
* Wed Mar 15 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.11
  see /usr/share/doc/packages/perl-HTML-Strip/Changes
  2.11  Tue 14 Mar 2023 13:18:29 EET
  - fix public VSC info for MetaCPAN (RT#115740)
  - add option to emit newlines for <br> and <p> tags
    (patch by Ryan Schmidt, contributed by Jason McIntosh)
  - installation / complilation bug on macOS (RT#134342)
    (patch contributed by Lucas Kanashiro)
  - spelling correction (RT#115740)
    (patch contributed by Florian Weimer)
  - improved C99 compatibility with utf8_char_width prototype (RT#146734)
    (contributed by Gabor Szabo)
  - htmlstrip command-line tool
* Thu May  5 2016 coolo@suse.com
- updated to 2.10
  see /usr/share/doc/packages/perl-HTML-Strip/Changes
  2.10  Fri Apr 22 12:16:17 BST 2016
  - fix to building on Windows / MSVC (RT#102389)
  - fix duplicate DESTROY in Strip(.pm,.xs) warning (RT#104379, Debian bug #785032)
* Thu Apr 16 2015 coolo@suse.com
- updated to 2.09
  see /usr/share/doc/packages/perl-HTML-Strip/Changes
  2.09  Mon Jan  5 16:51:17 GMT 2015
  - fixed latin1 support, added test case for it (RT#100969)
  2.08  Tue Dec  9 15:02:02 GMT 2014
  - replaced html entities in russian.html (read by utf8 test), as the
    test should not fail due to problems with HTML::Entities
  2.07  Thu Dec  4 14:07:03 GMT 2014
  - improvements for Kwalitee
  2.06  Thu Dec  4 12:59:54 GMT 2014
  - strip_spaces in utf8 test was using perl v5.14+ features
  - reading of DATA in utf8 test should be native utf8 not use Encode,
    which mangles it on some platforms
  2.05  Wed Dec  3 16:05:13 GMT 2014
  - fix to bug in t/300_utf8.t causing whitespace not to be stripped
  2.04  Tue Nov 25 11:14:08 GMT 2014
  - many cpan tester failures due to witespace in utf8 test,
    main test done with whitespace stripped, todo test as before
  2.03  Mon Nov 24 13:48:44 GMT 2014
  - removed trailing libicu deps
  - perl minimum version to 5.8 (needed for unicode support)
  - cleaned up test suite
  - version bump in META.YML (RT#100457)
  - 'use feature' breaking perl 5.8, removed (RT#100453)
  - added Test::Exception to build_requires
  2.02  Thu Nov 20 11:21:35 GMT 2014
  - removed dependency on libicu-dev, which isn't as universal as expected
    and was causing a bunch of cpan tester failures
  2.01  Wed Nov 19 10:48:04 GMT 2014
    (patch contributed by Michi Steiner)
  - clean buffer needs an extra char when emit_spaces=1 and the input has
    nothing to be removed (RT#41035)
  2.00  Tue Nov 18 16:14:42 GMT 2014
  - utf8 support via libicu (RT#42834)
  - smoke test and utf8 test, tests ordered
  1.10  Tue Sep 30 14:34:47 UTC 2014
  - Fix for RT#99207 (script mathematical symbol bug)
  1.09  Tue Sep 30 10:39:47 UTC 2014
  - offbyone.t disabled under Windows (RT#99219)
  1.08  Fri Sep 26 15:02:37 UTC 2014
  - system perl used in offbyone.t (RT#99151)
  1.07  Tue Sep 23 14:44:08 UTC 2014
  - fix to bug RT#19036 - tags not replaced with spaces when only a single
    character is between the tags
  - fix to bug RT#35345 - mathematical conparisons within <script> tags
    misunderstood
    (patches contributed by Adriano Ferreira)
  - Exporter was never needed
  - Allow other filtering operations than just decoding of HTML entities
  - Modernised test suite
  - Adds 'auto_reset' attribute, which allows automagic use of $hs->eof
  - fixes quotes in html comments (RT#32355)
    (patch contributed by Reini Urban)
  - MSVC doesnt define strcasecmp, use stricmp instead
    (patch contributed by Damyan Ivanov)
  - fixes POD errors
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Jul  7 2010 coolo@novell.com
- initial package created by cpanspec 1.78
